@@ -92,10 +92,7 @@ void FileNameSearchProtocol::searchDirectory(const KUrl& directory)
         if (!m_regExp || item.name().contains(*m_regExp)) {
             addItem = true;
         } else if (m_checkContent && item.determineMimeType()->is(QLatin1String("text/plain"))) {
-            qDebug() << "### Checking" << item;
             addItem = contentContainsPattern(item.url());
-        } else {
-            qDebug() << "### NOT Checking" << item;
         }
 
         if (addItem) {
